@@ -27,6 +27,6 @@
 /* build specific site-packages suffix. This is used to setup Python
  * module paths during initialization.
  */
-#define VTK_PYTHON_SITE_PACKAGES_SUFFIX "python3.8/site-packages"
+#define VTK_PYTHON_SITE_PACKAGES_SUFFIX "lib/python3.11/site-packages"
 
 #endif
